@@ -55,6 +55,7 @@ CURL_HTTP_VERSION_2TLS
 CURL_HTTP_VERSION_2_0
 CURL_HTTP_VERSION_2_PRIOR_KNOWLEDGE
 CURL_HTTP_VERSION_3
+CURL_HTTP_VERSION_3ONLY
 CURL_HTTP_VERSION_NONE
 CURL_IPRESOLVE_V4
 CURL_IPRESOLVE_V6
@@ -65,6 +66,7 @@ CURL_LOCK_ACCESS_SINGLE
 CURL_LOCK_DATA_CONNECT
 CURL_LOCK_DATA_COOKIE
 CURL_LOCK_DATA_DNS
+CURL_LOCK_DATA_HSTS
 CURL_LOCK_DATA_NONE
 CURL_LOCK_DATA_PSL
 CURL_LOCK_DATA_SHARE
@@ -75,6 +77,8 @@ CURL_MAX_WRITE_SIZE
 CURL_NETRC_IGNORED
 CURL_NETRC_OPTIONAL
 CURL_NETRC_REQUIRED
+CURL_PREREQFUNC_ABORT
+CURL_PREREQFUNC_OK
 CURL_PROGRESSFUNC_CONTINUE
 CURL_READFUNC_ABORT
 CURL_READFUNC_PAUSE
@@ -131,6 +135,7 @@ CURL_VERSION_BROTLI
 CURL_VERSION_CONV
 CURL_VERSION_CURLDEBUG
 CURL_VERSION_DEBUG
+CURL_VERSION_GSASL
 CURL_VERSION_GSSAPI
 CURL_VERSION_GSSNEGOTIATE
 CURL_VERSION_HSTS
@@ -150,20 +155,25 @@ CURL_VERSION_PSL
 CURL_VERSION_SPNEGO
 CURL_VERSION_SSL
 CURL_VERSION_SSPI
+CURL_VERSION_THREADSAFE
 CURL_VERSION_TLSAUTH_SRP
 CURL_VERSION_UNICODE
 CURL_VERSION_UNIX_SOCKETS
 CURL_VERSION_ZSTD
+CURL_WRITEFUNC_ERROR
 CURL_WRITEFUNC_PAUSE
 CURL_ZERO_TERMINATED
 CURLVERSION_EIGHTH
+CURLVERSION_ELEVENTH
 CURLVERSION_FIFTH
 CURLVERSION_FIRST
 CURLVERSION_FOURTH
+CURLVERSION_NINTH
 CURLVERSION_NOW
 CURLVERSION_SECOND
 CURLVERSION_SEVENTH
 CURLVERSION_SIXTH
+CURLVERSION_TENTH
 CURLVERSION_THIRD
 CURLUSESSL_ALL
 CURLUSESSL_CONTROL
@@ -180,9 +190,21 @@ CURLUPART_SCHEME
 CURLUPART_URL
 CURLUPART_USER
 CURLUPART_ZONEID
+CURLUE_BAD_FILE_URL
+CURLUE_BAD_FRAGMENT
 CURLUE_BAD_HANDLE
+CURLUE_BAD_HOSTNAME
+CURLUE_BAD_IPV6
+CURLUE_BAD_LOGIN
 CURLUE_BAD_PARTPOINTER
+CURLUE_BAD_PASSWORD
+CURLUE_BAD_PATH
 CURLUE_BAD_PORT_NUMBER
+CURLUE_BAD_QUERY
+CURLUE_BAD_SCHEME
+CURLUE_BAD_SLASHES
+CURLUE_BAD_USER
+CURLUE_LACKS_IDN
 CURLUE_MALFORMED_INPUT
 CURLUE_NO_FRAGMENT
 CURLUE_NO_HOST
@@ -192,6 +214,7 @@ CURLUE_NO_PORT
 CURLUE_NO_QUERY
 CURLUE_NO_SCHEME
 CURLUE_NO_USER
+CURLUE_NO_ZONEID
 CURLUE_OK
 CURLUE_OUT_OF_MEMORY
 CURLUE_UNKNOWN_PART
@@ -206,6 +229,7 @@ CURLSSLSET_OK
 CURLSSLSET_TOO_LATE
 CURLSSLSET_UNKNOWN_BACKEND
 CURLSSLOPT_ALLOW_BEAST
+CURLSSLOPT_AUTO_CLIENT_CERT
 CURLSSLOPT_NATIVE_CA
 CURLSSLOPT_NO_PARTIALCHAIN
 CURLSSLOPT_NO_REVOKE
@@ -224,6 +248,7 @@ CURLSSLBACKEND_NONE
 CURLSSLBACKEND_NSS
 CURLSSLBACKEND_OPENSSL
 CURLSSLBACKEND_POLARSSL
+CURLSSLBACKEND_RUSTLS
 CURLSSLBACKEND_SCHANNEL
 CURLSSLBACKEND_SECURETRANSPORT
 CURLSSLBACKEND_WOLFSSL
@@ -297,6 +322,7 @@ CURLPROTO_FILE
 CURLPROTO_FTP
 CURLPROTO_FTPS
 CURLPROTO_GOPHER
+CURLPROTO_GOPHERS
 CURLPROTO_HTTP
 CURLPROTO_HTTPS
 CURLPROTO_IMAP
@@ -344,9 +370,12 @@ CURLOPT_ALTSVC
 CURLOPT_ALTSVC_CTRL
 CURLOPT_APPEND
 CURLOPT_AUTOREFERER
+CURLOPT_AWS_SIGV4
 CURLOPT_BUFFERSIZE
 CURLOPT_CAINFO
+CURLOPT_CAINFO_BLOB
 CURLOPT_CAPATH
+CURLOPT_CA_CACHE_TIMEOUT
 CURLOPT_CERTINFO
 CURLOPT_CHUNK_BGN_FUNCTION
 CURLOPT_CHUNK_DATA
@@ -383,6 +412,9 @@ CURLOPT_DNS_LOCAL_IP6
 CURLOPT_DNS_SERVERS
 CURLOPT_DNS_SHUFFLE_ADDRESSES
 CURLOPT_DNS_USE_GLOBAL_CACHE
+CURLOPT_DOH_SSL_VERIFYHOST
+CURLOPT_DOH_SSL_VERIFYPEER
+CURLOPT_DOH_SSL_VERIFYSTATUS
 CURLOPT_DOH_URL
 CURLOPT_EGDSOCKET
 CURLOPT_ENCODING
@@ -463,10 +495,12 @@ CURLOPT_MAXAGE_CONN
 CURLOPT_MAXCONNECTS
 CURLOPT_MAXFILESIZE
 CURLOPT_MAXFILESIZE_LARGE
+CURLOPT_MAXLIFETIME_CONN
 CURLOPT_MAXREDIRS
 CURLOPT_MAX_RECV_SPEED_LARGE
 CURLOPT_MAX_SEND_SPEED_LARGE
 CURLOPT_MIMEPOST
+CURLOPT_MIME_OPTIONS
 CURLOPT_NETRC
 CURLOPT_NETRC_FILE
 CURLOPT_NEW_DIRECTORY_PERMS
@@ -490,11 +524,14 @@ CURLOPT_POSTFIELDSIZE_LARGE
 CURLOPT_POSTQUOTE
 CURLOPT_POSTREDIR
 CURLOPT_PREQUOTE
+CURLOPT_PREREQDATA
+CURLOPT_PREREQFUNCTION
 CURLOPT_PRE_PROXY
 CURLOPT_PRIVATE
 CURLOPT_PROGRESSDATA
 CURLOPT_PROGRESSFUNCTION
 CURLOPT_PROTOCOLS
+CURLOPT_PROTOCOLS_STR
 CURLOPT_PROXY
 CURLOPT_PROXYAUTH
 CURLOPT_PROXYHEADER
@@ -504,6 +541,7 @@ CURLOPT_PROXYTYPE
 CURLOPT_PROXYUSERNAME
 CURLOPT_PROXYUSERPWD
 CURLOPT_PROXY_CAINFO
+CURLOPT_PROXY_CAINFO_BLOB
 CURLOPT_PROXY_CAPATH
 CURLOPT_PROXY_CRLFILE
 CURLOPT_PROXY_ISSUERCERT
@@ -528,12 +566,14 @@ CURLOPT_PROXY_TLSAUTH_TYPE
 CURLOPT_PROXY_TLSAUTH_USERNAME
 CURLOPT_PROXY_TRANSFER_MODE
 CURLOPT_PUT
+CURLOPT_QUICK_EXIT
 CURLOPT_QUOTE
 CURLOPT_RANDOM_FILE
 CURLOPT_RANGE
 CURLOPT_READDATA
 CURLOPT_READFUNCTION
 CURLOPT_REDIR_PROTOCOLS
+CURLOPT_REDIR_PROTOCOLS_STR
 CURLOPT_REFERER
 CURLOPT_REQUEST_TARGET
 CURLOPT_RESOLVE
@@ -562,7 +602,10 @@ CURLOPT_SOCKS5_GSSAPI_NEC
 CURLOPT_SOCKS5_GSSAPI_SERVICE
 CURLOPT_SSH_AUTH_TYPES
 CURLOPT_SSH_COMPRESSION
+CURLOPT_SSH_HOSTKEYDATA
+CURLOPT_SSH_HOSTKEYFUNCTION
 CURLOPT_SSH_HOST_PUBLIC_KEY_MD5
+CURLOPT_SSH_HOST_PUBLIC_KEY_SHA256
 CURLOPT_SSH_KEYDATA
 CURLOPT_SSH_KEYFUNCTION
 CURLOPT_SSH_KNOWNHOSTS
@@ -633,6 +676,7 @@ CURLOPT_WRITEDATA
 CURLOPT_WRITEFUNCTION
 CURLOPT_WRITEHEADER
 CURLOPT_WRITEINFO
+CURLOPT_WS_OPTIONS
 CURLOPT_XFERINFODATA
 CURLOPT_XFERINFOFUNCTION
 CURLOPT_XOAUTH2_BEARER
@@ -645,6 +689,7 @@ CURLOPTTYPE_OFF_T
 CURLOPTTYPE_SLISTPOINT
 CURLOPTTYPE_STRINGPOINT
 CURLOPTTYPE_VALUES
+CURLM_ABORTED_BY_CALLBACK
 CURLM_ADDED_ALREADY
 CURLM_BAD_EASY_HANDLE
 CURLM_BAD_FUNCTION_ARGUMENT
@@ -656,6 +701,7 @@ CURLM_OK
 CURLM_OUT_OF_MEMORY
 CURLM_RECURSIVE_API_CALL
 CURLM_UNKNOWN_OPTION
+CURLM_UNRECOVERABLE_POLL
 CURLM_WAKEUP_FAILURE
 CURLMSG_DONE
 CURLMSG_NONE
@@ -675,6 +721,7 @@ CURLMOPT_SOCKETDATA
 CURLMOPT_SOCKETFUNCTION
 CURLMOPT_TIMERDATA
 CURLMOPT_TIMERFUNCTION
+CURLMIMEOPT_FORMESCAPE
 CURLKHTYPE_DSS
 CURLKHTYPE_ECDSA
 CURLKHTYPE_ED25519
@@ -697,6 +744,8 @@ CURLIOCMD_RESTARTREAD
 CURLINFO_ACTIVESOCKET
 CURLINFO_APPCONNECT_TIME
 CURLINFO_APPCONNECT_TIME_T
+CURLINFO_CAINFO
+CURLINFO_CAPATH
 CURLINFO_CERTINFO
 CURLINFO_CONDITION_UNMET
 CURLINFO_CONNECT_TIME
@@ -749,6 +798,7 @@ CURLINFO_REDIRECT_COUNT
 CURLINFO_REDIRECT_TIME
 CURLINFO_REDIRECT_TIME_T
 CURLINFO_REDIRECT_URL
+CURLINFO_REFERER
 CURLINFO_REQUEST_SIZE
 CURLINFO_RESPONSE_CODE
 CURLINFO_RETRY_AFTER
@@ -780,9 +830,16 @@ CURLINFO_TLS_SSL_PTR
 CURLINFO_TOTAL_TIME
 CURLINFO_TOTAL_TIME_T
 CURLINFO_TYPEMASK
-CURLINC_CURL_H
 CURLHSTS_ENABLE
 CURLHSTS_READONLYFILE
+CURLHE_BADINDEX
+CURLHE_BAD_ARGUMENT
+CURLHE_MISSING
+CURLHE_NOHEADERS
+CURLHE_NOREQUEST
+CURLHE_NOT_BUILT_IN
+CURLHE_OK
+CURLHE_OUT_OF_MEMORY
 CURLHEADER_SEPARATE
 CURLHEADER_UNIFIED
 CURLGSSAPI_DELEGATION_FLAG
@@ -925,12 +982,14 @@ CURLE_RTSP_CSEQ_ERROR
 CURLE_RTSP_SESSION_ERROR
 CURLE_SEND_ERROR
 CURLE_SEND_FAIL_REWIND
+CURLE_SETOPT_OPTION_SYNTAX
 CURLE_SHARE_IN_USE
 CURLE_SSH
 CURLE_SSL_CACERT
 CURLE_SSL_CACERT_BADFILE
 CURLE_SSL_CERTPROBLEM
 CURLE_SSL_CIPHER
+CURLE_SSL_CLIENTCERT
 CURLE_SSL_CONNECT_ERROR
 CURLE_SSL_CRL_BADFILE
 CURLE_SSL_ENGINE_INITFAILED
@@ -952,6 +1011,7 @@ CURLE_TFTP_UNKNOWNID
 CURLE_TOO_MANY_REDIRECTS
 CURLE_UNKNOWN_OPTION
 CURLE_UNKNOWN_TELNET_OPTION
+CURLE_UNRECOVERABLE_POLL
 CURLE_UNSUPPORTED_PROTOCOL
 CURLE_UPLOAD_FAILED
 CURLE_URL_MALFORMAT
@@ -967,6 +1027,7 @@ CURLCLOSEPOLICY_OLDEST
 CURLCLOSEPOLICY_SLOWEST
 CURLAUTH_ANY
 CURLAUTH_ANYSAFE
+CURLAUTH_AWS_SIGV4
 CURLAUTH_BASIC
 CURLAUTH_BEARER
 CURLAUTH_DIGEST
